@@ -57,7 +57,7 @@ def _ansi_partial_color_format_main(template, style="default", cmap=None, hide=F
         except Exception:
             msg = "Could not find color style {0!r}, using default."
             print(msg.format(style), file=sys.stderr)
-            builtins.__xonsh_env__["XONSH_COLOR_STYLE"] = "default"
+            builtins.__xonsh__.env["XONSH_COLOR_STYLE"] = "default"
             cmap = ANSI_STYLES["default"]
     formatter = string.Formatter()
     esc = ("\001" if hide else "") + "\033["
