@@ -12,6 +12,7 @@ import platform
 import functools
 import subprocess
 import collections
+import collections.abc as cabc
 import importlib.util
 
 from xonsh.lazyasd import LazyBool, lazyobject, lazybool
@@ -53,6 +54,10 @@ ON_FREEBSD = LazyBool(
     lambda: (sys.platform.startswith("freebsd")), globals(), "ON_FREEBSD"
 )
 """``True`` if on a FreeBSD operating system, else ``False``."""
+ON_DRAGONFLY = LazyBool(
+    lambda: (sys.platform.startswith("dragonfly")), globals(), "ON_DRAGONFLY"
+)
+"""``True`` if on a DragonFly BSD operating system, else ``False``."""
 ON_NETBSD = LazyBool(
     lambda: (sys.platform.startswith("netbsd")), globals(), "ON_NETBSD"
 )
@@ -62,7 +67,7 @@ ON_NETBSD = LazyBool(
 @lazybool
 def ON_BSD():
     """``True`` if on a BSD operating system, else ``False``."""
-    return bool(ON_FREEBSD) or bool(ON_NETBSD)
+    return bool(ON_FREEBSD) or bool(ON_NETBSD) or bool(ON_DRAGONFLY)
 
 
 @lazybool
@@ -343,7 +348,7 @@ def linux_distro():
     if ON_LINUX:
         if distro:
             ld = distro.id()
-        elif PYTHON_VERSION_INFO < (3, 7, 0):
+        elif PYTHON_VERSION_INFO < (3, 6, 6):
             ld = platform.linux_distribution()[0] or "unknown"
         elif "-ARCH-" in platform.platform():
             ld = "arch"  # that's the only one we need to know for now
@@ -378,7 +383,7 @@ def windows_bash_command():
     # Check that bash is on path otherwise try the default directory
     # used by Git for windows
     wbc = "bash"
-    cmd_cache = builtins.__xonsh_commands_cache__
+    cmd_cache = builtins.__xonsh__.commands_cache
     bash_on_path = cmd_cache.lazy_locate_binary("bash", ignore_alias=True)
     if bash_on_path:
         try:
@@ -411,7 +416,7 @@ def windows_bash_command():
 
 if ON_WINDOWS:
 
-    class OSEnvironCasePreserving(collections.MutableMapping):
+    class OSEnvironCasePreserving(cabc.MutableMapping):
         """ Case-preserving wrapper for os.environ on Windows.
             It uses nt.environ to get the correct cased keys on
             initialization. It also preserves the case of any variables
