@@ -83,7 +83,7 @@ RE_HIDDEN_BYTES = LazyObject(
 
 @lazyobject
 def RE_VT100_ESCAPE():
-    return re.compile(b"(\x9B|\x1B\[)[0-?]*[ -\/]*[@-~]")
+    return re.compile(b"(\x9B|\x1B\\[)[0-?]*[ -\\/]*[@-~]")
 
 
 @lazyobject
@@ -463,7 +463,7 @@ class ConsoleParallelReader(QueueReader):
         timeout : float, optional
             The queue reading timeout.
         """
-        timeout = timeout or builtins.__xonsh_env__.get("XONSH_PROC_FREQUENCY")
+        timeout = timeout or builtins.__xonsh__.env.get("XONSH_PROC_FREQUENCY")
         super().__init__(fd, timeout=timeout)
         self._buffer = buffer  # this cannot be public
         if buffer is None:
@@ -540,7 +540,7 @@ class PopenThread(threading.Thread):
     def __init__(self, *args, stdin=None, stdout=None, stderr=None, **kwargs):
         super().__init__()
         self.lock = threading.RLock()
-        env = builtins.__xonsh_env__
+        env = builtins.__xonsh__.env
         # stdin setup
         self.orig_stdin = stdin
         if stdin is None:
@@ -825,7 +825,7 @@ class PopenThread(threading.Thread):
     #
 
     def _signal_quit(self, signum, frame):
-        """Signal handler for quiting SIGQUIT - Ctrl+\ may have been pressed.
+        r"""Signal handler for quiting SIGQUIT - Ctrl+\ may have been pressed.
         """
         self.send_signal(signum)
         self._restore_sigquit(frame=frame)
@@ -1002,12 +1002,18 @@ class FileThreadDispatcher:
         """Registers a file handle for the current thread. Returns self so
         that this method can be used in a with-statement.
         """
+        if handle is self:
+            # prevent weird recurssion errors
+            return self
         self.registry[threading.get_ident()] = handle
         return self
 
     def deregister(self):
         """Removes the current thread from the registry."""
-        del self.registry[threading.get_ident()]
+        ident = threading.get_ident()
+        if ident in self.registry:
+            # don't remove if we have already been deregistered
+            del self.registry[threading.get_ident()]
 
     @property
     def available(self):
@@ -1303,7 +1309,7 @@ class ProcProxyThread(threading.Thread):
         self.stdin = stdin
         self.stdout = stdout
         self.stderr = stderr
-        self.env = env or builtins.__xonsh_env__
+        self.env = env or builtins.__xonsh__.env
         self._interrupted = False
 
         if ON_WINDOWS:
@@ -1357,7 +1363,7 @@ class ProcProxyThread(threading.Thread):
         if last_in_pipeline:
             capout = spec.captured_stdout  # NOQA
             caperr = spec.captured_stderr  # NOQA
-        env = builtins.__xonsh_env__
+        env = builtins.__xonsh__.env
         enc = env.get("XONSH_ENCODING")
         err = env.get("XONSH_ENCODING_ERRORS")
         if ON_WINDOWS:
@@ -1676,7 +1682,7 @@ class ProcProxy(object):
         """
         if self.f is None:
             return 0
-        env = builtins.__xonsh_env__
+        env = builtins.__xonsh__.env
         enc = env.get("XONSH_ENCODING")
         err = env.get("XONSH_ENCODING_ERRORS")
         spec = self._wait_and_getattr("spec")
@@ -1767,7 +1773,7 @@ def update_fg_process_group(pipeline_group, background):
         return False
     if not ON_POSIX:
         return False
-    env = builtins.__xonsh_env__
+    env = builtins.__xonsh__.env
     if not env.get("XONSH_INTERACTIVE"):
         return False
     return give_terminal_to(pipeline_group)
@@ -1888,7 +1894,7 @@ class CommandPipeline:
         proc = self.proc
         if proc is None:
             return
-        timeout = builtins.__xonsh_env__.get("XONSH_PROC_FREQUENCY")
+        timeout = builtins.__xonsh__.env.get("XONSH_PROC_FREQUENCY")
         # get the correct stdout
         stdout = proc.stdout
         if (
@@ -2011,7 +2017,7 @@ class CommandPipeline:
         yields each line. This may optionally accept lines (in bytes) to iterate
         over, in which case it does not call iterraw().
         """
-        env = builtins.__xonsh_env__
+        env = builtins.__xonsh__.env
         enc = env.get("XONSH_ENCODING")
         err = env.get("XONSH_ENCODING_ERRORS")
         lines = self.lines
@@ -2045,7 +2051,7 @@ class CommandPipeline:
         """Streams lines to sys.stderr and the errors attribute."""
         if not lines:
             return
-        env = builtins.__xonsh_env__
+        env = builtins.__xonsh__.env
         enc = env.get("XONSH_ENCODING")
         err = env.get("XONSH_ENCODING_ERRORS")
         b = b"".join(lines)
@@ -2063,7 +2069,7 @@ class CommandPipeline:
         # do some munging of the line before we save it to the attr
         b = b.replace(b"\r\n", b"\n").replace(b"\r", b"\n")
         b = RE_HIDE_ESCAPE.sub(b"", b)
-        env = builtins.__xonsh_env__
+        env = builtins.__xonsh__.env
         s = b.decode(
             encoding=env.get("XONSH_ENCODING"), errors=env.get("XONSH_ENCODING_ERRORS")
         )
@@ -2078,7 +2084,7 @@ class CommandPipeline:
         if not b:
             return ""
         if isinstance(b, bytes):
-            env = builtins.__xonsh_env__
+            env = builtins.__xonsh__.env
             s = b.decode(
                 encoding=env.get("XONSH_ENCODING"),
                 errors=env.get("XONSH_ENCODING_ERRORS"),
@@ -2130,12 +2136,12 @@ class CommandPipeline:
             return
         if give_terminal_to(pgid):  # if gave term succeed
             self.term_pgid = pgid
-            if hasattr(builtins, "__xonsh_shell__"):
+            if hasattr(builtins.__xonsh__, "shell"):
                 # restoring sanity could probably be called whenever we return
                 # control to the shell. But it only seems to matter after a
                 # ^Z event. This *has* to be called after we give the terminal
                 # back to the shell.
-                builtins.__xonsh_shell__.shell.restore_tty_sanity()
+                builtins.__xonsh__.shell.shell.restore_tty_sanity()
 
     def resume(self, job, tee_output=True):
         self.ended = False
@@ -2232,7 +2238,7 @@ class CommandPipeline:
 
     def _apply_to_history(self):
         """Applies the results to the current history object."""
-        hist = builtins.__xonsh_history__
+        hist = builtins.__xonsh__.history
         if hist is not None:
             hist.last_cmd_rtn = 1 if self.proc is None else self.proc.returncode
 
@@ -2244,7 +2250,7 @@ class CommandPipeline:
             not spec.is_proxy
             and rtn is not None
             and rtn > 0
-            and builtins.__xonsh_env__.get("RAISE_SUBPROC_ERROR")
+            and builtins.__xonsh__.env.get("RAISE_SUBPROC_ERROR")
         ):
             try:
                 raise subprocess.CalledProcessError(rtn, spec.cmd, output=self.output)
@@ -2367,7 +2373,7 @@ class CommandPipeline:
         """Prefix to print in front of stderr, as bytes."""
         p = self._stderr_prefix
         if p is None:
-            env = builtins.__xonsh_env__
+            env = builtins.__xonsh__.env
             t = env.get("XONSH_STDERR_PREFIX")
             s = format_std_prepost(t, env=env)
             p = s.encode(
@@ -2382,7 +2388,7 @@ class CommandPipeline:
         """Postfix to print after stderr, as bytes."""
         p = self._stderr_postfix
         if p is None:
-            env = builtins.__xonsh_env__
+            env = builtins.__xonsh__.env
             t = env.get("XONSH_STDERR_POSTFIX")
             s = format_std_prepost(t, env=env)
             p = s.encode(
@@ -2413,7 +2419,10 @@ def pause_call_resume(p, f, *args, **kwargs):
         hasattr(p, "send_signal") and ON_POSIX and not ON_MSYS and not ON_CYGWIN
     )
     if can_send_signal:
-        p.send_signal(signal.SIGSTOP)
+        try:
+            p.send_signal(signal.SIGSTOP)
+        except PermissionError:
+            pass
     try:
         f(*args, **kwargs)
     except Exception:
@@ -2448,7 +2457,7 @@ class PrevProcCloser(threading.Thread):
             return
         proc = pipeline.proc
         prev_end_time = None
-        timeout = builtins.__xonsh_env__.get("XONSH_PROC_FREQUENCY")
+        timeout = builtins.__xonsh__.env.get("XONSH_PROC_FREQUENCY")
         sleeptime = min(timeout * 1000, 0.1)
         while proc.poll() is None:
             if not check_prev_done:
