@@ -66,24 +66,24 @@ xp = _LazyModule.load('xonsh', 'xonsh.platform', 'xp')
 def _replace_home(x):
     if xp.ON_WINDOWS:
         home = (
-            builtins.__xonsh_env__["HOMEDRIVE"] + builtins.__xonsh_env__["HOMEPATH"][0]
+            builtins.__xonsh__.env["HOMEDRIVE"] + builtins.__xonsh__.env["HOMEPATH"][0]
         )
         if x.startswith(home):
             x = x.replace(home, "~", 1)
 
-        if builtins.__xonsh_env__.get("FORCE_POSIX_PATHS"):
+        if builtins.__xonsh__.env.get("FORCE_POSIX_PATHS"):
             x = x.replace(os.sep, os.altsep)
 
         return x
     else:
-        home = builtins.__xonsh_env__["HOME"]
+        home = builtins.__xonsh__.env["HOME"]
         if x.startswith(home):
             x = x.replace(home, "~", 1)
         return x
 
 
 def _replace_home_cwd():
-    return _replace_home(builtins.__xonsh_env__["PWD"])
+    return _replace_home(builtins.__xonsh__.env["PWD"])
 
 
 def _collapsed_pwd():
@@ -100,8 +100,8 @@ def _dynamically_collapsed_pwd():
     environment variable DYNAMIC_CWD_WIDTH.
     """
     original_path = _replace_home_cwd()
-    target_width, units = builtins.__xonsh_env__["DYNAMIC_CWD_WIDTH"]
-    elision_char = builtins.__xonsh_env__["DYNAMIC_CWD_ELISION_CHAR"]
+    target_width, units = builtins.__xonsh__.env["DYNAMIC_CWD_WIDTH"]
+    elision_char = builtins.__xonsh__.env["DYNAMIC_CWD_ELISION_CHAR"]
     if target_width == float("inf"):
         return original_path
     if units == "%":
@@ -153,9 +153,9 @@ def env_name(pre_chars="(", post_chars=")"):
     """Extract the current environment name from $VIRTUAL_ENV or
     $CONDA_DEFAULT_ENV if that is set
     """
-    env_path = builtins.__xonsh_env__.get("VIRTUAL_ENV", "")
+    env_path = builtins.__xonsh__.env.get("VIRTUAL_ENV", "")
     if len(env_path) == 0 and xp.ON_ANACONDA:
-        env_path = builtins.__xonsh_env__.get("CONDA_DEFAULT_ENV", "")
+        env_path = builtins.__xonsh__.env.get("CONDA_DEFAULT_ENV", "")
     env_name = os.path.basename(env_path)
     if env_name:
         return pre_chars + env_name + post_chars
@@ -168,7 +168,7 @@ def vte_new_tab_cwd():
     on startup. Note that this does not return a string, it simply prints
     and flushes the escape sequence to stdout directly.
     """
-    env = builtins.__xonsh_env__
+    env = builtins.__xonsh__.env
     t = "\033]7;file://{}{}\007"
     s = t.format(env.get("HOSTNAME"), env.get("PWD"))
     print(s, end="", flush=True)
@@ -203,13 +203,13 @@ GitStatus = collections.namedtuple(
 def _check_output(*args, **kwargs):
     kwargs.update(
         dict(
-            env=builtins.__xonsh_env__.detype(),
+            env=builtins.__xonsh__.env.detype(),
             stdout=subprocess.PIPE,
             stderr=subprocess.DEVNULL,
             universal_newlines=True,
         )
     )
-    timeout = builtins.__xonsh_env__["VC_BRANCH_TIMEOUT"]
+    timeout = builtins.__xonsh__.env["VC_BRANCH_TIMEOUT"]
     # See https://docs.python.org/3/library/subprocess.html#subprocess.Popen.communicate
     with subprocess.Popen(*args, **kwargs) as proc:
         try:
@@ -255,7 +255,7 @@ def _DEFS():
 
 
 def _get_def(key):
-    def_ = builtins.__xonsh_env__.get("XONSH_GITSTATUS_" + key)
+    def_ = builtins.__xonsh__.env.get("XONSH_GITSTATUS_" + key)
     return def_ if def_ is not None else _DEFS[key]
 
 
@@ -405,7 +405,7 @@ threading = _LazyModule.load('threading', 'threading')
 # amalgamated subprocess
 # amalgamated xonsh.tools
 def _get_git_branch(q):
-    denv = builtins.__xonsh_env__.detype()
+    denv = builtins.__xonsh__.env.detype()
     try:
         branches = xt.decode_bytes(
             subprocess.check_output(
@@ -434,7 +434,7 @@ def get_git_branch():
     be determined (timeout, not in a git repo, etc.) then this returns None.
     """
     branch = None
-    timeout = builtins.__xonsh_env__.get("VC_BRANCH_TIMEOUT")
+    timeout = builtins.__xonsh__.env.get("VC_BRANCH_TIMEOUT")
     q = queue.Queue()
 
     t = threading.Thread(target=_get_git_branch, args=(q,))
@@ -448,7 +448,7 @@ def get_git_branch():
 
 
 def _get_hg_root(q):
-    _curpwd = builtins.__xonsh_env__["PWD"]
+    _curpwd = builtins.__xonsh__.env["PWD"]
     while True:
         if not os.path.isdir(_curpwd):
             return False
@@ -466,7 +466,7 @@ def get_hg_branch(root=None):
     """Try to get the mercurial branch of the current directory,
     return None if not in a repo or subprocess.TimeoutExpired if timed out.
     """
-    env = builtins.__xonsh_env__
+    env = builtins.__xonsh__.env
     timeout = env["VC_BRANCH_TIMEOUT"]
     q = queue.Queue()
     t = threading.Thread(target=_get_hg_root, args=(q,))
@@ -507,7 +507,7 @@ _FIRST_BRANCH_TIMEOUT = True
 
 def _first_branch_timeout_message():
     global _FIRST_BRANCH_TIMEOUT
-    sbtm = builtins.__xonsh_env__["SUPPRESS_BRANCH_TIMEOUT_MESSAGE"]
+    sbtm = builtins.__xonsh__.env["SUPPRESS_BRANCH_TIMEOUT_MESSAGE"]
     if not _FIRST_BRANCH_TIMEOUT or sbtm:
         return
     _FIRST_BRANCH_TIMEOUT = False
@@ -530,7 +530,7 @@ def current_branch():
     '<branch-timeout>' is returned.
     """
     branch = None
-    cmds = builtins.__xonsh_commands_cache__
+    cmds = builtins.__xonsh__.commands_cache
     # check for binary only once
     if cmds.is_empty():
         has_git = bool(cmds.locate_binary("git", ignore_alias=True))
@@ -550,7 +550,7 @@ def current_branch():
 
 def _git_dirty_working_directory(q, include_untracked):
     status = None
-    denv = builtins.__xonsh_env__.detype()
+    denv = builtins.__xonsh__.env.detype()
     try:
         cmd = ["git", "status", "--porcelain"]
         if include_untracked:
@@ -568,7 +568,7 @@ def git_dirty_working_directory(include_untracked=False):
     """Returns whether or not the git directory is dirty. If this could not
     be determined (timeout, file not found, etc.) then this returns None.
     """
-    timeout = builtins.__xonsh_env__.get("VC_BRANCH_TIMEOUT")
+    timeout = builtins.__xonsh__.env.get("VC_BRANCH_TIMEOUT")
     q = queue.Queue()
     t = threading.Thread(
         target=_git_dirty_working_directory, args=(q, include_untracked)
@@ -585,7 +585,7 @@ def hg_dirty_working_directory():
     """Computes whether or not the mercurial working directory is dirty or not.
     If this cannot be determined, None is returned.
     """
-    env = builtins.__xonsh_env__
+    env = builtins.__xonsh__.env
     cwd = env["PWD"]
     denv = env.detype()
     vcbt = env["VC_BRANCH_TIMEOUT"]
@@ -615,7 +615,7 @@ def dirty_working_directory():
     None. Currently supports git and hg.
     """
     dwd = None
-    cmds = builtins.__xonsh_commands_cache__
+    cmds = builtins.__xonsh__.commands_cache
     if cmds.lazy_locate_binary("git", ignore_alias=True):
         dwd = git_dirty_working_directory()
     if cmds.lazy_locate_binary("hg", ignore_alias=True) and dwd is None:
@@ -688,7 +688,7 @@ class PromptFormatter:
     def __call__(self, template=DEFAULT_PROMPT, fields=None):
         """Formats a xonsh prompt template string."""
         if fields is None:
-            self.fields = builtins.__xonsh_env__.get("PROMPT_FIELDS", PROMPT_FIELDS)
+            self.fields = builtins.__xonsh__.env.get("PROMPT_FIELDS", PROMPT_FIELDS)
         else:
             self.fields = fields
         try:
@@ -713,7 +713,7 @@ class PromptFormatter:
         if field is None:
             return
         elif field.startswith("$"):
-            val = builtins.__xonsh_env__[field[1:]]
+            val = builtins.__xonsh__.env[field[1:]]
             return _format_value(val, spec, conv)
         elif field in self.fields:
             val = self._get_field_value(field)
@@ -812,7 +812,7 @@ def multiline_prompt(curr=""):
     # tail is the trailing whitespace
     tail = line if headlen == 0 else line.rsplit(head[-1], 1)[1]
     # now to construct the actual string
-    dots = builtins.__xonsh_env__.get("MULTILINE_PROMPT")
+    dots = builtins.__xonsh__.env.get("MULTILINE_PROMPT")
     dots = dots() if callable(dots) else dots
     if dots is None or len(dots) == 0:
         return ""
@@ -858,7 +858,7 @@ def is_template_string(template, PROMPT_FIELDS=None):
         return False
     included_names.discard(None)
     if PROMPT_FIELDS is None:
-        fmtter = builtins.__xonsh_env__.get("PROMPT_FIELDS", PROMPT_FIELDS)
+        fmtter = builtins.__xonsh__.env.get("PROMPT_FIELDS", PROMPT_FIELDS)
     else:
         fmtter = PROMPT_FIELDS
     known_names = set(fmtter.keys())
